@@ -3,19 +3,20 @@ use warnings;
 
 package WebService::Gitter;
 
-require LWP::UserAgent;
 use Moo;
+use LWP::UserAgent;
 use JSON::MaybeXS;
 
-
 #ABSTRACT: An interface to Gitter REST API via Perl 5.
-our $VERSION = '0.4.1'; # VERSION
+our $VERSION = '0.4.2'; # VERSION
 
+# The API/Token key
 has token_pass => (
     is       => 'ro',
     required => 1
 );
 
+# We set up timeout for 30 seconds.
 my $ua = LWP::UserAgent->new;
 $ua->timeout(30);
 $ua->env_proxy;
@@ -25,15 +26,13 @@ my $url_rooms = 'https://api.gitter.im/v1/rooms';
 my $url_user  = 'https://api.gitter.im/v1/user';
 
 # This method send a GET request to a server to get authentication data as the authenticated user.
-
 sub current_user {
     my $self = shift;
 
     my $req = $ua->get( "$url_user/me?access_token=" . $self->token_pass );
 
     if ( $req->is_success ) {
-	decode_json $req->decoded_content;
-
+        decode_json $req->decoded_content;
 
     }
 
@@ -43,6 +42,7 @@ sub current_user {
 
 }
 
+# List users in the room
 sub room_users {
     my ( $self, $id ) = @_;
     my $req =
@@ -57,6 +57,7 @@ sub room_users {
     }
 }
 
+# List user (you) joined rooms.
 sub rooms {
     my $self = shift;
 
@@ -72,6 +73,7 @@ sub rooms {
     }
 }
 
+# Return room ID by passing room name/room uri
 sub room_id {
     my ( $self, $uri ) = @_;
 
@@ -93,6 +95,8 @@ sub room_id {
     }
 }
 
+
+# Send message to the room id
 sub send_message {
     my ( $self, $message, $room_id ) = @_;
 
@@ -114,6 +118,8 @@ sub send_message {
     }
 }
 
+# List all messages in the room you on (via name/uri). You can set the returned messages limit for the room you chose.
+# By default, the messages limit are 5.
 sub messages {
     my ( $self, $room_id, $limit ) = @_;
 
@@ -147,7 +153,7 @@ WebService::Gitter - An interface to Gitter REST API via Perl 5.
 
 =head1 VERSION
 
-version 0.4.1
+version 0.4.2
 
 =head1 SYNOPSIS
 
